pub struct StorageKey<T> {
    /// The key of the 32-byte-long storage slot.
    slot: b256,
    /// The offset, *in words*, starting from the beginning of the `slot`.
    offset: u64,
    /// The unique identifier for the storage slot being referred to, used by zero-sized _storage types_.
    field_id: b256,
}
Describes a location in storage, made of slots of 32 bytes in size,
at which a value of type T can be read or written.

Additional Information

The location in storage is specified by the b256 key of a particular storage slot and an
offset, given in words, from the start of that slot. The parameter T is the type of
the data to be read from or written to at the offset.

The T must be a non-zero-sized type in order to be written to or read from storage.

Depending on the size of T and the offset, reading or writing a value of type T
may require accessing multiple consecutive storage slots.

A value can share the slot with another values within the same storage slot.

If T is a zero-sized type, no storage access will occur. Moreover, if T is a zero-sized type,
StorageKey will assume that it is a storage type, i.e., a type that provides a custom access
to the storage. StorageVec, StorageString, and StorageBytes given in the Sway
standard library are all examples of storage types.

The field_id is a unique identifier for the storage slot being referred to.
It is used for zero-sized storage types to differentiate between multiple zero-sized storage entries
that might live at the same storage location but represent different storage constructs.

Fields

slot: b256

The key of the 32-byte-long storage slot.

offset: u64

The offset, in words, starting from the beginning of the slot.

field_id: b256

The unique identifier for the storage slot being referred to, used by zero-sized storage types.